﻿using UnityEngine;
using System.Collections;

public class CharacterControllerBase : MonoBehaviour
{
    public float SpeedScalar = 1f;
    public float Terminal = 0.3f;

    protected Animator Controller;
    // Use this for initialization
    void Start()
    {
        Controller = GetComponent<Animator>();
    }

    bool HorizontalActive = false;
    bool VerticalActive = false;

    protected virtual void InnerUpdate()
    {
        if (CharacterSelector.Instance.CurrentCharacter == this)
        {
            var vertAxis = Input.GetAxis("Vertical");
            var horAxis = Input.GetAxis("Horizontal");

            if(vertAxis != 0 && !HorizontalActive)
            {
                VerticalActive = true;
            }
            else
            {
                VerticalActive = false;
            }

            if(horAxis != 0 && !VerticalActive)
            {
                HorizontalActive = true;
            }
            else
            {
                HorizontalActive = false;
            }

            Controller.SetFloat("VerticalSpeed", vertAxis);
            Controller.SetFloat("HorizontalSpeed", horAxis);
            Controller.SetBool("Stopped", vertAxis == 0f && horAxis == 0f);
            Controller.SetBool("VerticalActive", VerticalActive);
            Controller.SetBool("HorizontalActive", HorizontalActive);

            var delta = new Vector3(Mathf.Sign(horAxis) * Mathf.Min(Mathf.Abs(SpeedScalar * horAxis), Terminal), Mathf.Sign(vertAxis) * Mathf.Min(Mathf.Abs(SpeedScalar * vertAxis), Terminal), 0f);
            this.gameObject.transform.position += delta;
        }
    }

    // Update is called once per frame
    void Update()
    {
        InnerUpdate();
    }
}
